import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.constant.db_name_constant as db_name_constant
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.api.ths.zt.ths_stock_zt_pool_api as ths_stock_zt_pool_api
from mns_common.utils.async_fun import async_fun
import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api

mongodb_util = MongodbUtil('27017')
import mns_common.utils.data_frame_util as data_frame_util
import time
from loguru import logger
import pandas as pd
from datetime import datetime


# 添加主线和涨停分析临时数据
def merge_main_line_info(str_day, data_df):
    # 保证数据完整性
    if 'main_line' not in data_df.columns:
        data_df['main_line'] = ''
    else:
        data_df.fillna({'main_line': ''}, inplace=True)

    if 'sub_main_line' not in data_df.columns:
        data_df['sub_main_line'] = ''
    else:
        data_df.fillna({'sub_main_line': ''}, inplace=True)

    if 'zt_analysis' not in data_df.columns:
        data_df['zt_analysis'] = ''

    else:
        data_df.fillna({'zt_analysis': ''}, inplace=True)

    if 'zt_reason' not in data_df.columns:
        data_df['zt_reason'] = ''
    else:
        data_df.fillna({'zt_reason': ''}, inplace=True)

    if 'main_line_choose_source' not in data_df.columns:
        data_df['main_line_choose_source'] = 'now_zt'
    else:
        data_df.fillna({'main_line_choose_source': 'now_zt'}, inplace=True)

    if 'main_line_grade' not in data_df.columns:
        data_df['main_line_grade'] = 1
    else:
        data_df.fillna({'main_line_grade': 1}, inplace=True)

    query_zt_now = {'symbol': {"$in": list(data_df['symbol'])}, 'str_day': str_day}
    # merge 主线 涨停详情
    main_line_detail_df = mongodb_util.find_query_data(db_name_constant.MAIN_LINE_DETAIL, query_zt_now)
    if data_frame_util.is_not_empty(main_line_detail_df):
        symbol_mapping_zt_reason_now = dict(
            zip(main_line_detail_df['symbol'], main_line_detail_df['zt_reason']))

        symbol_mapping_zt_analysis_now = dict(
            zip(main_line_detail_df['symbol'], main_line_detail_df['zt_analysis']))

        symbol_mapping_main_line_now = dict(
            zip(main_line_detail_df['symbol'], main_line_detail_df['main_line']))

        symbol_mapping_sub_main_line_now = dict(
            zip(main_line_detail_df['symbol'], main_line_detail_df['sub_main_line']))

        symbol_mapping_main_line_choose_source = dict(
            zip(main_line_detail_df['symbol'], main_line_detail_df['main_line_choose_source']))

        symbol_mapping_main_line_grade = dict(
            zip(main_line_detail_df['symbol'], main_line_detail_df['main_line_grade']))

        data_df['main_line_grade'] = data_df['symbol'].map(
            symbol_mapping_main_line_grade).fillna(
            data_df['main_line_grade'])

        data_df['main_line'] = data_df['symbol'].map(
            symbol_mapping_main_line_now).fillna(
            data_df['main_line'])

        data_df['sub_main_line'] = data_df['symbol'].map(
            symbol_mapping_sub_main_line_now).fillna(
            data_df['sub_main_line'])
        data_df['zt_reason'] = data_df['symbol'].map(
            symbol_mapping_zt_reason_now).fillna(
            data_df['zt_reason'])
        data_df['zt_analysis'] = data_df['symbol'].map(
            symbol_mapping_zt_analysis_now).fillna(
            data_df['zt_analysis'])

        data_df['main_line_choose_source'] = data_df['symbol'].map(
            symbol_mapping_main_line_choose_source).fillna(
            data_df['main_line_choose_source'])

    return data_df


# merge涨停分析 原因
def merge_zt_reason_info(str_day, data_df):
    if 'zt_analysis' not in data_df.columns:
        data_df['zt_analysis'] = ''

    else:
        data_df.fillna({'zt_analysis': ''}, inplace=True)

    if 'zt_reason' not in data_df.columns:
        data_df['zt_reason'] = ''
    else:
        data_df.fillna({'zt_reason': ''}, inplace=True)

    query_zt_now = {'symbol': {"$in": list(data_df['symbol'])}, 'str_day': str_day}
    # merge 主线 涨停详情
    zt_reason_analysis_df = mongodb_util.find_query_data(db_name_constant.ZT_REASON_ANALYSIS, query_zt_now)
    if data_frame_util.is_not_empty(zt_reason_analysis_df):
        symbol_mapping_zt_reason_now = dict(
            zip(zt_reason_analysis_df['symbol'], zt_reason_analysis_df['zt_reason']))

        symbol_mapping_zt_analysis_now = dict(
            zip(zt_reason_analysis_df['symbol'], zt_reason_analysis_df['zt_analysis']))

        data_df['zt_reason'] = data_df['symbol'].map(
            symbol_mapping_zt_reason_now).fillna(
            data_df['zt_reason'])
        data_df['zt_analysis'] = data_df['symbol'].map(
            symbol_mapping_zt_analysis_now).fillna(
            data_df['zt_analysis'])

    return data_df


def update_zt_reason_analysis(symbol, str_day, name, need_update):
    try:
        key_id = symbol + "_" + str_day
        query_zt = {"_id": key_id}

        # 已经存在的数据
        zt_reason_analysis_exists_df = mongodb_util.find_query_data(db_name_constant.ZT_REASON_ANALYSIS,
                                                                    query_zt)

        if data_frame_util.is_not_empty(zt_reason_analysis_exists_df):
            zt_analysis = list(zt_reason_analysis_exists_df['zt_analysis'])[0]
            zt_reason = list(zt_reason_analysis_exists_df['zt_reason'])[0]
            # 需要更新数据
            if data_frame_util.is_string_empty(zt_analysis) or data_frame_util.is_string_empty(
                    zt_reason) or need_update:
                try:
                    zt_result_dict = ths_stock_zt_pool_api.zt_analyse_reason(symbol)
                    zt_analysis = zt_result_dict['zt_analyse_detail']
                    zt_reason = zt_result_dict['zt_reason']
                    time.sleep(1)
                except BaseException as e:
                    time.sleep(1)
                    zt_analysis = ''
                    zt_reason = ''

                zt_reason_analysis_exists_df['zt_analysis'] = zt_analysis
                zt_reason_analysis_exists_df['zt_reason'] = zt_reason
                now_date = datetime.now()
                str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
                zt_reason_analysis_exists_df['str_now_date'] = str_now_date
                mongodb_util.save_mongo(zt_reason_analysis_exists_df, db_name_constant.ZT_REASON_ANALYSIS)
        else:
            # 不存在临时主线数据
            try:
                zt_result_dict = ths_stock_zt_pool_api.zt_analyse_reason(symbol)
                zt_analysis = zt_result_dict['zt_analyse_detail']
                zt_reason = zt_result_dict['zt_reason']
                time.sleep(1)
            except BaseException as e:
                time.sleep(1)
                zt_analysis = ''
                zt_reason = ''
            now_date = datetime.now()
            str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
            reason_dict = {'_id': key_id,
                           'symbol': symbol,
                           'name': name,
                           'zt_analysis': zt_analysis,
                           'zt_reason': zt_reason,
                           'str_day': str_day,
                           'update_time': str_now_date,
                           }
            reason_df = pd.DataFrame(reason_dict, index=[1])
            mongodb_util.save_mongo(reason_df, db_name_constant.ZT_REASON_ANALYSIS)
    except BaseException as e:
        logger.error("添加涨停原因详情异常:{},{}", e, name)


@async_fun
def update_symbol_list_zt_reason_analysis(data_df, need_update):
    for stock_one in data_df.itertuples():
        str_day = stock_one.str_day
        symbol = stock_one.symbol
        name = stock_one.name
        update_zt_reason_analysis(symbol, str_day, name, need_update)
        time.sleep(1)


# 保存连板股票主线
@async_fun
def save_last_trade_day_main_line(str_day, stock_em_zt_pool_df_data):
    last_trade_day = trade_date_common_service_api.get_last_trade_day(str_day)
    stock_em_zt_pool_connected_df = stock_em_zt_pool_df_data.loc[
        stock_em_zt_pool_df_data['connected_boards_numbers'] > 1]
    if data_frame_util.is_empty(stock_em_zt_pool_connected_df):
        return
    else:
        query = {'str_day': last_trade_day, 'symbol': {"$in": list(stock_em_zt_pool_connected_df['symbol'])}}
        last_trade_day_main_line_detail_df = mongodb_util.find_query_data(db_name_constant.MAIN_LINE_DETAIL, query)
        if data_frame_util.is_empty(last_trade_day_main_line_detail_df):
            return
        else:
            last_trade_day_main_line_detail_df['_id'] = last_trade_day_main_line_detail_df['symbol'] + '_' + str_day
            last_trade_day_main_line_detail_df['str_day'] = str_day
            last_trade_day_main_line_detail_df['connected_boards_numbers'] = last_trade_day_main_line_detail_df[
                                                                                 'connected_boards_numbers'] + 1
            now_date = datetime.now()
            str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
            last_trade_day_main_line_detail_df['update_time'] = str_now_date
            today_exist_main_line_df = mongodb_util.find_query_data(db_name_constant.MAIN_LINE_DETAIL,
                                                                    {'str_day': str_day, 'symbol': {"$in": list(
                                                                        last_trade_day_main_line_detail_df['symbol'])}})
            if data_frame_util.is_not_empty(today_exist_main_line_df):
                today_new_main_line_df = last_trade_day_main_line_detail_df.loc[~
                last_trade_day_main_line_detail_df['symbol'].isin(list(today_exist_main_line_df['symbol']))]
            else:
                today_new_main_line_df = last_trade_day_main_line_detail_df.copy()
            mongodb_util.save_mongo(today_new_main_line_df, db_name_constant.MAIN_LINE_DETAIL)


if __name__ == '__main__':
    update_zt_reason_analysis('600362', '2025-12-26', '江西铜业', True)



import os
import sys

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
from loguru import logger
import requests
import time
import mns_common.component.proxies.proxy_common_api as proxy_common_api
from concurrent.futures import ThreadPoolExecutor
import json
import mns_common.component.cookie.cookie_info_service as cookie_info_service

# 分页条数
page_number = 100

fields = ("f352,f2,f3,f5,f6,f8,f10,f11,f22,f12,f14,f15,f16,f17,f18,f20,f21,f26,"
          "f33,f34,f35,f62,f66,f69,f72,f100,f184,f211,f212,f103,f383")


def get_hk_stock_count(pn, proxies, page_size, cookie, time_out):
    try:
        headers = {
            'Cookie': cookie
        }
        current_timestamp = str(int(round(time.time() * 1000, 0)))

        url_new = ('https://push2.eastmoney.com/api/qt/clist/get?cb=jQuery371026074131356896413_' + str(
            current_timestamp) +
                   '&np=1'
                   '&fltt=1'
                   '&invt=2'
                   '&fs=m:128+t:3,m:128+t:4,m:128+t:1,m:128+t:2'
                   '&fields=' + fields +
                   '&fid=f12'
                   '&pn=' + str(pn) +
                   '&pz=' + str(page_size) +
                   '&po=1'
                    '&dect=1'
                   '&ut=fa5fd1943c7b386f172d6893dbfba10b'
                   '&wbp2u=4253366368931142|0|1|0|web'
                   '&_' + str(current_timestamp))

        if proxies is None:
            r = requests.get(url_new, headers=headers, timeout=time_out)
        else:
            r = requests.get(url_new, headers=headers, proxies=proxies, timeout=time_out)
        result = r.content.decode("utf-8")
        begin_index_total = result.index('"total":')
        end_index_total = result.index('"diff"')
        return int(result[begin_index_total + 8:end_index_total - 1])
    except Exception as e:
        logger.error("获取港股股票列表,实时行情异常:{}", e)
        return 0


def get_hk_real_time_quotes_page_df(pn, proxies, page_size, cookie, time_out):
    try:
        headers = {
            'Cookie': cookie
        }
        current_timestamp = str(int(round(time.time() * 1000, 0)))
        url_new = ('https://61.push2.eastmoney.com/api/qt/clist/get?cb=jQuery112409497467688484127_' + str(
            current_timestamp) +
                   '&pn=' + str(pn) +
                   '&pz=' + str(page_size) +
                   '&po=1'
                   '&np=3'
                   '&ut=bd1d9ddb04089700cf9c27f6f7426281'
                   '&fltt=2'
                   '&invt=2'
                   '&wbp2u=4253366368931142|0|1|0|web'
                   '&fid=f12'
                   '&fs=m:116+t:3,m:116+t:4,m:116+t:1,m:116+t:2'
                   '&fields=' + fields +
                   '&_=' + str(current_timestamp))

        if proxies is None:
            r = requests.get(url_new, headers=headers, timeout=time_out)
        else:
            r = requests.get(url_new, headers=headers, proxies=proxies, timeout=time_out)
        result = r.content.decode("utf-8")
        startIndex = result.index('"diff"')
        endIndex = result.index('}]}')
        result = result[startIndex + 7:endIndex + 2]
        data_json = json.loads(result)
        temp_df = pd.DataFrame(data_json)
        return temp_df
    except Exception as e:
        logger.error("获取港股列表,实时行情异常:{}", e)
        return pd.DataFrame()


# 改名
def rename_hk_field(temp_df):
    temp_df = temp_df.rename(columns={
        "f12": "symbol",
        "f14": "name",
        "f3": "chg",
        "f2": "now_price",
        "f5": "volume",
        "f6": "amount",
        "f8": "exchange",
        "f10": "quantity_ratio",
        "f22": "up_speed",
        "f11": "up_speed_05",
        "f15": "high",
        "f16": "low",
        "f17": "open",
        "f18": "yesterday_price",
        "f20": "total_mv",
        "f21": "flow_mv",
        "f26": "list_date",
        "f33": "wei_bi",
        "f34": "outer_disk",
        "f35": "inner_disk",
        "f62": "today_main_net_inflow",
        "f66": "super_large_order_net_inflow",
        "f69": "super_large_order_net_inflow_ratio",
        "f72": "large_order_net_inflow",
        # "f78": "medium_order_net_inflow",
        # "f84": "small_order_net_inflow",
        "f100": "industry",
        "f103": "concept_name_str",
        "f383": "concept_code_str",
        "f184": "today_main_net_inflow_ratio",
        "f352": "average_price",
        "f211": "buy_1_num",
        "f212": "sell_1_num"
    })
    temp_df.loc[temp_df['buy_1_num'] == '-', 'buy_1_num'] = 0
    temp_df.loc[temp_df['sell_1_num'] == '-', 'sell_1_num'] = 0
    temp_df.loc[temp_df['up_speed_05'] == '-', 'up_speed_05'] = 0
    temp_df.loc[temp_df['up_speed'] == '-', 'up_speed'] = 0
    temp_df.loc[temp_df['average_price'] == '-', 'average_price'] = 0
    temp_df.loc[temp_df['wei_bi'] == '-', 'wei_bi'] = 0
    temp_df.loc[temp_df['yesterday_price'] == '-', 'yesterday_price'] = 0
    temp_df.loc[temp_df['now_price'] == '-', 'now_price'] = 0
    temp_df.loc[temp_df['chg'] == '-', 'chg'] = 0
    temp_df.loc[temp_df['volume'] == '-', 'volume'] = 0
    temp_df.loc[temp_df['amount'] == '-', 'amount'] = 0
    temp_df.loc[temp_df['exchange'] == '-', 'exchange'] = 0
    temp_df.loc[temp_df['quantity_ratio'] == '-', 'quantity_ratio'] = 0
    temp_df.loc[temp_df['high'] == '-', 'high'] = 0
    temp_df.loc[temp_df['low'] == '-', 'low'] = 0
    temp_df.loc[temp_df['open'] == '-', 'open'] = 0
    temp_df.loc[temp_df['total_mv'] == '-', 'total_mv'] = 0
    temp_df.loc[temp_df['flow_mv'] == '-', 'flow_mv'] = 0
    temp_df.loc[temp_df['inner_disk'] == '-', 'inner_disk'] = 0
    temp_df.loc[temp_df['outer_disk'] == '-', 'outer_disk'] = 0
    temp_df.loc[temp_df['today_main_net_inflow_ratio'] == '-', 'today_main_net_inflow_ratio'] = 0
    temp_df.loc[temp_df['today_main_net_inflow'] == '-', 'today_main_net_inflow'] = 0
    temp_df.loc[temp_df['super_large_order_net_inflow'] == '-', 'super_large_order_net_inflow'] = 0
    temp_df.loc[temp_df['super_large_order_net_inflow_ratio'] == '-', 'super_large_order_net_inflow_ratio'] = 0
    temp_df.loc[temp_df['large_order_net_inflow'] == '-', 'large_order_net_inflow'] = 0
    # temp_df.loc[temp_df['medium_order_net_inflow'] == '-', 'medium_order_net_inflow'] = 0
    # temp_df.loc[temp_df['small_order_net_inflow'] == '-', 'small_order_net_inflow'] = 0

    temp_df["list_date"] = pd.to_numeric(temp_df["list_date"], errors="coerce")
    temp_df["wei_bi"] = pd.to_numeric(temp_df["wei_bi"], errors="coerce")
    temp_df["average_price"] = pd.to_numeric(temp_df["average_price"], errors="coerce")
    temp_df["yesterday_price"] = pd.to_numeric(temp_df["yesterday_price"], errors="coerce")
    temp_df["now_price"] = pd.to_numeric(temp_df["now_price"], errors="coerce")
    temp_df["chg"] = pd.to_numeric(temp_df["chg"], errors="coerce")
    temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
    temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
    temp_df["exchange"] = pd.to_numeric(temp_df["exchange"], errors="coerce")
    temp_df["quantity_ratio"] = pd.to_numeric(temp_df["quantity_ratio"], errors="coerce")
    temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
    temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
    temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
    temp_df["total_mv"] = pd.to_numeric(temp_df["total_mv"], errors="coerce")
    temp_df["flow_mv"] = pd.to_numeric(temp_df["flow_mv"], errors="coerce")
    temp_df["outer_disk"] = pd.to_numeric(temp_df["outer_disk"], errors="coerce")
    temp_df["inner_disk"] = pd.to_numeric(temp_df["inner_disk"], errors="coerce")
    temp_df["today_main_net_inflow"] = pd.to_numeric(temp_df["today_main_net_inflow"], errors="coerce")
    temp_df["super_large_order_net_inflow"] = pd.to_numeric(temp_df["super_large_order_net_inflow"],
                                                            errors="coerce")
    temp_df["super_large_order_net_inflow_ratio"] = pd.to_numeric(temp_df["super_large_order_net_inflow_ratio"],
                                                                  errors="coerce")
    temp_df["large_order_net_inflow"] = pd.to_numeric(temp_df["large_order_net_inflow"],
                                                      errors="coerce")
    # temp_df["medium_order_net_inflow"] = pd.to_numeric(temp_df["medium_order_net_inflow"],
    #                                                    errors="coerce")
    # temp_df["small_order_net_inflow"] = pd.to_numeric(temp_df["small_order_net_inflow"], errors="coerce")

    # 大单比例
    temp_df['large_order_net_inflow_ratio'] = round((temp_df['large_order_net_inflow'] / temp_df['amount']) * 100,
                                                    2)

    # 外盘是内盘倍数
    temp_df['disk_ratio'] = round((temp_df['outer_disk'] - temp_df['inner_disk']) / temp_df['inner_disk'], 2)
    # 只有外盘没有内盘
    temp_df.loc[temp_df["inner_disk"] == 0, ['disk_ratio']] = 1688
    temp_df['disk_diff_amount'] = round(
        (temp_df['outer_disk'] - temp_df['inner_disk']) * temp_df[
            "average_price"],
        2)
    return temp_df


def all_hk_stock_ticker_data_new(initial_proxies, time_out, em_cookie, max_number) -> pd.DataFrame:
    """
    使用多线程获取所有股票数据，失败页面会使用新IP重试，最多使用10个IP
    """
    per_page = page_number
    total_pages = (max_number + per_page - 1) // per_page  # 向上取整
    all_pages = set(range(1, total_pages + 1))  # 所有需要获取的页码
    success_pages = set()  # 成功获取的页码
    results = []  # 存储成功获取的数据
    used_ip_count = 1  # 已使用IP计数器（初始IP算第一个）
    MAX_IP_LIMIT = 10  # IP使用上限

    # 循环处理直到所有页面成功或达到IP上限
    while (all_pages - success_pages) and (used_ip_count < MAX_IP_LIMIT):
        # 获取当前需要处理的失败页码
        current_failed_pages = all_pages - success_pages
        if used_ip_count > 1:
            logger.info("当前需要处理的失败页码: {}, 已使用IP数量: {}/{}", current_failed_pages, used_ip_count,
                        MAX_IP_LIMIT)

        # 首次使用初始代理，后续获取新代理
        if len(success_pages) == 0:
            proxies = initial_proxies
        else:
            # 每次重试前获取新代理并计数
            # logger.info("获取新代理IP处理失败页面")
            new_proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
            proxies = {"https": new_proxy_ip}
            # logger.info("新代理IP: {}, 已使用IP数量: {}/{}", new_proxy_ip, used_ip_count + 1, MAX_IP_LIMIT)
            used_ip_count += 1  # 增加IP计数器

        # 创建线程池处理当前失败的页码
        with ThreadPoolExecutor(max_workers=10) as executor:
            futures = {
                executor.submit(get_hk_real_time_quotes_page_df, pn, proxies,
                                per_page, em_cookie, time_out): pn
                for pn in current_failed_pages
            }

            # 收集结果并记录成功页码
            for future, pn in futures.items():
                try:
                    result = future.result()
                    if not result.empty:
                        results.append(result)
                        success_pages.add(pn)
                    # else:
                    #     logger.warning("页码 {} 未返回有效数据", pn)
                except Exception as e:
                    continue
                    # logger.error("页码 {} 处理异常: {}", pn, str(e))

    # 检查是否达到IP上限
    if used_ip_count >= MAX_IP_LIMIT and (all_pages - success_pages):
        remaining_pages = all_pages - success_pages
        logger.warning("已达到最大IP使用限制({}个)，剩余未获取页码: {}, 返回现有数据", MAX_IP_LIMIT, remaining_pages)

    # 合并所有成功获取的数据
    if results:
        return pd.concat(results, ignore_index=True)
    else:
        return pd.DataFrame()


def get_hk_real_time_quotes(time_out, em_cookie):
    try_numer = 3
    while try_numer > 0:
        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
        initial_proxies = {"https": proxy_ip,
                           "http": proxy_ip}

        max_number = get_hk_stock_count(1, initial_proxies, 20, em_cookie, time_out)
        if max_number > 0:
            break
        try_numer = try_numer - 1
    if max_number == 0:
        return pd.DataFrame()
    all_hk_stock_ticker_data_new_df = all_hk_stock_ticker_data_new(initial_proxies, time_out, em_cookie, max_number)
    return rename_hk_field(all_hk_stock_ticker_data_new_df)


if __name__ == '__main__':
    em_cookie_test = cookie_info_service.get_em_cookie()
    get_hk_real_time_quotes(30, em_cookie_test)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

# db_name
######################################[数据库]##############################################################
EXTRA_INCOME = 'extraIncome'

# us_stock 美股信息数据表
US_STOCK = 'us_stock'
# a股数据表
A_STOCK = 'a_stock'
# hk股票数据
HK_STOCK = 'hk_stock'
######################################[集合表]##############################################################
# 东方财富a股信息
EM_A_STOCK_INFO = 'em_a_stock_info'

# 东方财富A股 ETF信息
EM_ETF_INFO = 'em_etf_info'

# 东方财富A股 KZZ信息
EM_KZZ_INFO = 'em_kzz_info'

# 东方财富HK股信息
EM_HK_STOCK_INFO = 'em_hk_stock_info'

# 东方财富港股通信息
EM_HK_GGT_STOCK_INFO = 'em_hk_ggt_stock_info'

# 创业板分钟集合数据
ONE_MINUTE_K_LINE_BFQ_C = 'one_minute_k_line_bfq_c'

# 北交所分钟集合数据
ONE_MINUTE_K_LINE_BFQ_BJ = 'one_minute_k_line_bfq_bj'

# 上海主板分钟集合数据
ONE_MINUTE_K_LINE_BFQ_H = 'one_minute_k_line_bfq_h'

# 科创板分钟集合数据
ONE_MINUTE_K_LINE_BFQ_K = 'one_minute_k_line_bfq_k'

# 深圳主板分钟集合数据
ONE_MINUTE_K_LINE_BFQ_S = 'one_minute_k_line_bfq_s'

# 可转债分钟集合数据
ONE_MINUTE_K_LINE_BFQ_KZZ = 'one_minute_k_line_bfq_kzz'

# ETF分钟集合数据
ONE_MINUTE_K_LINE_BFQ_ETF = 'one_minute_k_line_bfq_etf'

# 沪深主要指数分钟集合数据
ONE_MINUTE_K_LINE_BFQ_MAIN_INDEX = 'one_minute_k_line_bfq_main_index'
# 沪深主要指数前复权k线
INDEX_QFQ_DAILY = 'index_qfq_daily'

# 可转债qfq 日k线
KZZ_QFQ_DAILY = 'kzz_qfq_daily'
# ETF qfq 日k线
ETF_QFQ_DAILY = 'etf_qfq_daily'

# 一分钟同步失败集合

ONE_MINUTE_SYNC_FAIL = 'one_minute_sync_fail'

# us stock daily_k_line


# 雪球利润表
XUE_QIU_LRB_INCOME = 'xue_qiu_lrb_income'

# 雪球资产负债表
XUE_QIU_ASSET_DEBT = 'xue_qiu_asset_debt'

# 雪球资产现金流量表
XUE_QIU_CASH_FLOW = 'xue_qiu_cash_flow'

# todo A股日k线
# A 可转债前复权日k线
A_KZZ_QFQ_DAILY = 'a_kzz_qfq_daily'

# A ETF前复权日k线
A_ETF_QFQ_DAILY = 'a_etf_qfq_daily'

# A 股票前复权日k线
A_STOCK_QFQ_DAILY = 'a_stock_qfq_daily'

# A 指数前复权日k线
A_INDEX_QFQ_DAILY = 'a_index_qfq_daily'

# todo 港股
# HK ETF前复权日k线
HK_ETF_QFQ_DAILY = 'hk_etf_qfq_daily'

# HK 股票前复权日k线
HK_STOCK_QFQ_DAILY = 'hk_stock_qfq_daily'

# hk stock daily_k_line
HK_STOCK_DAILY_QFQ_K_LINE = 'hk_stock_daily_qfq_k_line'
# hk stock 1分钟集合数据
HK_STOCK_MINUTE_K_LINE_BFQ = 'hk_stock_one_minute_k_line_bfq'

# hk etf 1分钟集合数据
HK_ETF_MINUTE_K_LINE_BFQ = 'hk_etf_one_minute_k_line_bfq'

# todo US 美股
# 东方财富US股信息
US_STOCK_INFO_EM = 'us_stock_info_em'

# 东方财富US ETF信息
US_ETF_INFO_EM = 'us_etf_info_em'

# alpha_vantage US股票信息
US_STOCK_INFO_ALPHA_VANTAGE = 'us_stock_info_alpha_vantage'

# alpha_vantage US ETF信息
US_STOCK_INFO_ALPHA_VANTAGE = 'us_etf_info_alpha_vantage'
# 美股公司信息 清洗表
US_STOCK_LIST = 'us_stock_list'
# 美ETF信息 清洗表
US_ETF_LIST = 'us_etf_list'
# 美股所属行业信息
US_STOCK_INDUSTRY_LIST = 'us_stock_industry_list'
# 美股所属概念信息
US_STOCK_CONCEPT_LIST = 'us_stock_concept_list'

# todo 日k线集合
# US ETF前复权日k线
US_ETF_QFQ_DAILY = 'us_etf_qfq_daily'
# US ETF不复权日k线
US_ETF_BFQ_DAILY = 'us_etf_bfq_daily'
# US ETF后复权日k线
US_ETF_HFQ_DAILY = 'us_etf_hfq_daily'

# us stock 日k线前复权
US_STOCK_DAILY_QFQ_K_LINE = 'us_stock_daily_qfq_k_line'
# us stock 日k线不复权
US_STOCK_DAILY_BFQ_K_LINE = 'us_stock_daily_bfq_k_line'
# us stock 日k线后复权
US_STOCK_DAILY_HFQ_K_LINE = 'us_stock_daily_hfq_k_line'

# todo 一分钟集合
# us stock 1分钟集合数据
US_STOCK_MINUTE_K_LINE_BFQ = 'us_stock_one_minute_k_line_bfq'

# us etf 1分钟集合数据
US_ETF_MINUTE_K_LINE_BFQ = 'us_etf_one_minute_k_line_bfq'

# us 主要etf 1分钟集合数据
US_MAIN_ETF_MINUTE_K_LINE_BFQ = 'us_main_etf_one_minute_k_line_bfq'



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)

from loguru import logger
import pandas as pd
import requests
from bs4 import BeautifulSoup


# 获取股票基本信息
# https://basic.10jqka.com.cn/mobile/301016/companyprofilen.html?showtab=1&broker=anelicaiapp
def get_company_info(symbol: str = "688272") -> pd.DataFrame:
    url = f"http://basic.10jqka.com.cn/mobile/{symbol}/companyprofilen.html?broker=pingan"
    headers = {
        "User-Agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 15_4_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 iOS AYLCAPP/9.1.2.0/h4526a24eb9445522492fd64caae11b1f scheme/anelicaiapp deviceinfo/I|9.1.2.0|NA|h4526a24eb9445522492fd64caae11b1f pastheme/0",
        "Cookie": "ps_login_app_name=AYLCAPP;ps_login_token_id=N_C993F777ACC500B354C762A2627A8862348FC8163799A08EBEB2301C28A2135D220475787D0E81425C1134E15D8CC8761D639FEDBD46C00FE8EA6482C1E42D9801B19918FB3F5C34;ps_login_union_id=edc29089a2b64e3882062297030a0386;PAS.CURRENTUNIONID=edc29089a2b64e3882062297030a0386"
    }
    r = requests.get(url, headers=headers)
    soup = BeautifulSoup(r.content.decode("utf-8"), 'lxml')
    soup.find('table', attrs={'class': 'leveldatail-tab'}).find_all('tr')
    temp_df = pd.read_html(r.content)[0]
    temp_df = temp_df.T
    temp_df = temp_df.iloc[1:2]
    temp_df.rename(columns={
        0: "name",
        1: "former_name",
        2: "registered_address",
        3: "chairman",
        4: "board_secretary",
        5: "main_business",
        6: "company_type",
        7: "controlling_shareholder",
        8: "actual_controller",
        9: "ultimate_controller",
        10: "list_date",
        11: "issue_price",
        12: "number_workers",
        13: "tel",
        14: "url",
        15: "email"
    }, inplace=True)

    return temp_df


# 获取股票详细信息
# HK市场 https://basic.10jqka.com.cn/mobile/HK1456/profile.html  https://basic.10jqka.com.cn/mobile/HK1456/company.html
# https://basic.10jqka.com.cn/new/HK1456/company.html
# https://basic.10jqka.com.cn/astockph/briefinfo/index.html?showhead=0&fromshare=1&code=300430&marketid=33&client_userid=ESgcM&back_source=hyperlink&share_hxapp=isc&fontzoom=no#/company/ziliao
def get_company_info_detail(symbol: str = "688272", market_id: str = "31") -> pd.DataFrame:
    url = f'https://basic.10jqka.com.cn/basicapi/company_info/merge_info/v1/base_info/?code={symbol}&market={market_id}&type=stock'
    headers = {
        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:105.0) Gecko/20100101 Firefox/105.0',
        'Host': 'basic.10jqka.com.cn',
        'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8',
        'Accept-Language': 'zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2',
        'Accept-Encoding': 'gzip, deflate, br',
        'Connection': 'keep-alive',
        'Cookie': 'v=A0CN8EBXN21LtMtpV6ldAxf6Ec8XySSbxq14l7rRDNvuNe77Ytn0Ixa9SDQJ',
        'Upgrade-Insecure-Requests': '1',

    }
    r = requests.get(url, headers=headers)
    data_json = r.json()
    status_code = data_json['status_code']
    status_msg = data_json['status_msg']
    if status_code != 0 or status_msg != 'success':
        logger.error("获取symbol公司详细信息异常:{}", symbol)
        return pd.DataFrame()
    if len(data_json['data']['industry']) == 0:
        return pd.DataFrame()
    data_df = pd.DataFrame(data_json['data']['industry'], index=[0])
    data_df = data_df[[
        'hy',
        'hycode',
        'hy2',
        'hy2code',
        'hy3',
        'hy3code',
    ]]

    business_nature = data_json['data']['business_nature']
    name = data_json['data']['code_name']
    intro = data_json['data']['intro']
    base_business = data_json['data']['base_business']

    address = data_json['data']['address']
    data_df['symbol'] = symbol
    data_df['name'] = name

    data_df['business_nature'] = business_nature

    if len(data_json['data']['management']['holder_controller']) > 0:
        holder_controller = pd.DataFrame(data_json['data']['management']['holder_controller'])
        holder_controller_name = str(list(holder_controller['name'])).strip('[').strip(']').replace("'", "")
        holder_controller_rate = holder_controller['rate']
        data_df['holder_controller_name'] = holder_controller_name
        data_df['holder_controller_rate'] = sum(holder_controller_rate)
    else:
        data_df['holder_controller_name'] = '暂无'
        data_df['holder_controller_rate'] = 0
    if len(data_json['data']['management']['final_controller']) > 0:
        final_controller = pd.DataFrame(data_json['data']['management']['final_controller'])
        final_controller_name = str(list(final_controller['name'])).strip('[').strip(']').replace("'", "")
        final_controller_rate = sum(final_controller['rate'])
        data_df['final_controller_name'] = final_controller_name
        data_df['final_controller_rate'] = final_controller_rate
    else:
        data_df['final_controller_name'] = '暂无'
        data_df['final_controller_rate'] = 0
    if len(data_json['data']['management']['actual_controller']) > 0:
        actual_controller = pd.DataFrame(data_json['data']['management']['actual_controller'])
        actual_controller_name = str(list(actual_controller['name'])).strip('[').strip(']').replace("'", "")
        actual_controller_rate = sum(actual_controller['rate'])
        data_df['actual_controller_name'] = actual_controller_name
        data_df['actual_controller_rate'] = actual_controller_rate
    else:
        data_df['actual_controller_name'] = '暂无'
        data_df['actual_controller_rate'] = 0

    data_df['base_business'] = base_business
    data_df['intro'] = intro
    data_df['address'] = address
    market_id = data_json['data']['market_id']
    data_df['market_id'] = market_id
    # 初始化数据
    data_df['main_business_list'] = [[]]
    data_df['most_profitable_business'] = ''
    data_df['most_profitable_business_rate'] = ''
    data_df['most_profitable_business_profit'] = ''

    # 业务构成
    main_business_list = data_json['data']['main_business']

    if len(main_business_list) > 0:
        # 最盈利业务
        profitable_business = data_json['data']['profitable_business']

        data_df['main_business_list'] = [main_business_list]

        most_profitable_business = profitable_business['name']

        most_profitable_business_rate = profitable_business['profit_rate']

        most_profitable_business_profit = profitable_business['profit']

        data_df['most_profitable_business'] = most_profitable_business
        data_df['most_profitable_business_rate'] = most_profitable_business_rate
        data_df['most_profitable_business_profit'] = most_profitable_business_profit
    return data_df


if __name__ == '__main__':
    get_company_info_detail('603683','17')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import akshare as ak
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.utils.date_handle_util as date_handle_util
from loguru import logger
import mns_common.component.em.em_stock_info_api as em_stock_info_api
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.component.company.company_common_service_new_api as company_common_service_new_api
from datetime import datetime

mongodb_util = MongodbUtil('27017')


# 获取十大股东

def get_stock_gdfx_free_top_10_em_api(str_day, symbol):
    try:
        stock_gdfx_free_top_10_em_df = ak.stock_gdfx_free_top_10_em(symbol=symbol, date=str_day)
        stock_gdfx_free_top_10_em_df.rename(columns={
            "名次": "index",
            "股东名称": "shareholder_name",
            "股东性质": "shareholder_nature",
            "股份性质": "shares_nature",
            "股份类型": "shares_type",
            "持股数": "shares_number",
            "占总流通股本持股比例": "circulation_ratio",
            "增减": "change",
            "变动比率": "change_ratio"
        }, inplace=True)
    except BaseException as e:
        # logger.error("同步十大流通股东信息异常:{}", e)
        return None
    stock_gdfx_free_top_10_em_df = stock_gdfx_free_top_10_em_df.fillna(0)
    stock_gdfx_free_top_10_em_df.index = stock_gdfx_free_top_10_em_df.index.astype(str)
    stock_gdfx_free_top_10_em_df.drop_duplicates('shareholder_name', keep='last', inplace=True)

    return stock_gdfx_free_top_10_em_df


def get_stock_gdfx_top_10_em_api(str_day, symbol):
    try:
        stock_gdfx_top_10_em_df = ak.stock_gdfx_top_10_em(symbol=symbol, date=str_day)
        stock_gdfx_top_10_em_df.rename(columns={
            "名次": "index",
            "股东名称": "shareholder_name",
            "股份类型": "shares_type",
            "持股数": "shares_number",
            "占总股本持股比例": "circulation_ratio",
            "增减": "change",
            "变动比率": "change_ratio"
        }, inplace=True)
    except BaseException as e:
        # logger.error("同步十大股东信息异常:{}", e)
        return None
    stock_gdfx_top_10_em_df = stock_gdfx_top_10_em_df.fillna(0)
    stock_gdfx_top_10_em_df.index = stock_gdfx_top_10_em_df.index.astype(str)
    stock_gdfx_top_10_em_df.drop_duplicates('shareholder_name', keep='last', inplace=True)
    return stock_gdfx_top_10_em_df


def get_stock_gdfx_free_top_10_em(str_day, symbol):
    symbol_init = symbol
    classification = common_service_fun_api.classify_symbol_one(symbol)
    if classification in ["S", "C"]:
        symbol = 'sz' + symbol
    elif classification in ["K", "H"]:
        symbol = 'sh' + symbol
    else:
        symbol = 'bj' + symbol

    str_day_no_slash = date_handle_util.no_slash_date(str_day)
    date_day = date_handle_util.str_to_date(str_day_no_slash, '%Y%m%d')
    month = date_day.month
    year = date_day.year
    one = '0331'
    two = '0630'
    three = '0930'
    four = '1231'

    if 0 < month <= 4:
        period_04 = str(year - 1) + four
        # 流通十大股东
        stock_gdfx_free_top_10_04 = get_stock_gdfx_free_top_10_em_api(period_04, symbol)
        sync_stock_gdfx_free_top_10(stock_gdfx_free_top_10_04, period_04, symbol_init, str_day)

        # 十大股东
        stock_gdfx_top_10_04 = get_stock_gdfx_top_10_em_api(period_04, symbol)
        sync_stock_gdfx_top_10(stock_gdfx_top_10_04, period_04, symbol_init, str_day)

        if stock_gdfx_free_top_10_04 is None or stock_gdfx_free_top_10_04.shape[0] == 0:
            period_03 = str(year - 1) + three
            stock_gdfx_free_top_10_03 = get_stock_gdfx_free_top_10_em_api(period_03, symbol)
            sync_stock_gdfx_free_top_10(stock_gdfx_free_top_10_03, period_03, symbol_init, str_day)

            # 十大股东
            stock_gdfx_top_10_03 = get_stock_gdfx_top_10_em_api(period_03, symbol)
            sync_stock_gdfx_top_10(stock_gdfx_top_10_03, period_03, symbol_init, str_day)

        period_01 = str(year) + one
        stock_gdfx_free_top_10_01 = get_stock_gdfx_free_top_10_em_api(period_01, symbol)
        sync_stock_gdfx_free_top_10(stock_gdfx_free_top_10_01, period_01, symbol_init, str_day)

        # 十大股东
        stock_gdfx_top_10_01 = get_stock_gdfx_top_10_em_api(period_01, symbol)
        sync_stock_gdfx_top_10(stock_gdfx_top_10_01, period_01, symbol_init, str_day)

    elif 4 < month <= 6:
        # 十大流通股东
        period_01 = str(year) + one
        stock_gdfx_free_top_10_01 = get_stock_gdfx_free_top_10_em_api(period_01, symbol)
        sync_stock_gdfx_free_top_10(stock_gdfx_free_top_10_01, period_01, symbol_init, str_day)
        period_02 = str(year) + two
        stock_gdfx_free_top_10_02 = get_stock_gdfx_free_top_10_em_api(period_02, symbol)
        sync_stock_gdfx_free_top_10(stock_gdfx_free_top_10_02, period_02, symbol_init, str_day)

        # 十大股东
        stock_gdfx_top_10_01 = get_stock_gdfx_top_10_em_api(period_01, symbol)
        sync_stock_gdfx_top_10(stock_gdfx_top_10_01, period_01, symbol_init, str_day)

        stock_gdfx_top_10_02 = get_stock_gdfx_top_10_em_api(period_02, symbol)
        sync_stock_gdfx_top_10(stock_gdfx_top_10_02, period_02, symbol_init, str_day)

    elif 6 < month <= 10:
        # 十大流通股东
        period_02 = str(year) + two
        stock_gdfx_free_top_10_02 = get_stock_gdfx_free_top_10_em_api(period_02, symbol)
        sync_stock_gdfx_free_top_10(stock_gdfx_free_top_10_02, period_02, symbol_init, str_day)
        period_03 = str(year) + three
        stock_gdfx_free_top_10_03 = get_stock_gdfx_free_top_10_em_api(period_03, symbol)
        sync_stock_gdfx_free_top_10(stock_gdfx_free_top_10_03, period_03, symbol_init, str_day)

        # 十大股东

        stock_gdfx_top_10_02 = get_stock_gdfx_top_10_em_api(period_02, symbol)
        sync_stock_gdfx_top_10(stock_gdfx_top_10_02, period_02, symbol_init, str_day)

        stock_gdfx_top_10_03 = get_stock_gdfx_top_10_em_api(period_03, symbol)
        sync_stock_gdfx_top_10(stock_gdfx_top_10_03, period_03, symbol_init, str_day)
    elif 10 < month <= 12:
        # 十大流通股东
        period_03 = str(year) + three
        stock_gdfx_free_top_10_03 = get_stock_gdfx_free_top_10_em_api(period_03, symbol)
        sync_stock_gdfx_free_top_10(stock_gdfx_free_top_10_03, period_03, symbol_init, str_day)
        period_04 = str(year) + four
        stock_gdfx_free_top_10_04 = get_stock_gdfx_free_top_10_em_api(period_04, symbol)
        sync_stock_gdfx_free_top_10(stock_gdfx_free_top_10_04, period_04, symbol_init, str_day)

        # 十大股东
        stock_gdfx_top_10_03 = get_stock_gdfx_top_10_em_api(period_03, symbol)
        sync_stock_gdfx_top_10(stock_gdfx_top_10_03, period_03, symbol_init, str_day)

        stock_gdfx_top_10_04 = get_stock_gdfx_top_10_em_api(period_04, symbol)
        sync_stock_gdfx_top_10(stock_gdfx_top_10_04, period_04, symbol_init, str_day)


# 保存10大流通股东
def sync_stock_gdfx_free_top_10(stock_gdfx_free_top_10_em_df, period, symbol, str_day):
    if stock_gdfx_free_top_10_em_df is not None and stock_gdfx_free_top_10_em_df.shape[0] > 0:
        # 更新日期
        stock_gdfx_free_top_10_em_df['str_day'] = str_day

        stock_gdfx_free_top_10_em_df['symbol'] = symbol

        stock_gdfx_free_top_10_em_df['shares_number_str'] = stock_gdfx_free_top_10_em_df['shares_number'].astype(str)

        stock_gdfx_free_top_10_em_df[
            '_id'] = symbol + '_' + period + '_' + stock_gdfx_free_top_10_em_df.shares_number_str
        stock_gdfx_free_top_10_em_df['period'] = period

        query_exist = {'symbol': symbol, 'period': period}
        exist_df = mongodb_util.find_query_data(db_name_constant.STOCK_GDFX_FREE_TOP_10, query_exist)
        now_date = datetime.now()
        str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
        # 不存在的时候更新创建时间
        if exist_df.shape[0] == 0:
            stock_gdfx_free_top_10_em_df['create_day'] = str_day
            stock_gdfx_free_top_10_em_df['sync_time'] = str_now_date
        else:
            if 'create_day' in exist_df.columns:
                stock_gdfx_free_top_10_em_df['create_day'] = list(exist_df['create_day'])[0]
            else:
                stock_gdfx_free_top_10_em_df['create_day'] = str_day
            if 'sync_time' in exist_df.columns:
                stock_gdfx_free_top_10_em_df['sync_time'] = list(exist_df['sync_time'])[0]
            else:
                stock_gdfx_free_top_10_em_df['sync_time'] = str_now_date
        mongodb_util.save_mongo(stock_gdfx_free_top_10_em_df, db_name_constant.STOCK_GDFX_FREE_TOP_10)


# 保存10大股东
def sync_stock_gdfx_top_10(stock_gdfx_top_10_em_df, period, symbol, str_day):
    if stock_gdfx_top_10_em_df is not None and stock_gdfx_top_10_em_df.shape[0] > 0:
        stock_gdfx_top_10_em_df['str_day'] = str_day
        stock_gdfx_top_10_em_df['symbol'] = symbol

        stock_gdfx_top_10_em_df['shares_number_str'] = stock_gdfx_top_10_em_df['shares_number'].astype(str)

        stock_gdfx_top_10_em_df['_id'] = symbol + '_' + period + '_' + stock_gdfx_top_10_em_df.shares_number_str
        stock_gdfx_top_10_em_df['period'] = period

        query_exist = {'symbol': symbol, 'period': period}
        exist_df = mongodb_util.find_query_data(db_name_constant.STOCK_GDFX_TOP_10, query_exist)
        now_date = datetime.now()
        str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')

        # 不存在的时候更新创建时间
        if exist_df.shape[0] == 0:
            stock_gdfx_top_10_em_df['create_day'] = str_day
            stock_gdfx_top_10_em_df['sync_time'] = str_now_date
        else:
            if 'create_day' in exist_df.columns:
                stock_gdfx_top_10_em_df['create_day'] = list(exist_df['create_day'])[0]


            else:
                stock_gdfx_top_10_em_df['create_day'] = str_day

            if 'sync_time' in exist_df.columns:
                stock_gdfx_top_10_em_df['sync_time'] = list(exist_df['sync_time'])[0]
            else:
                stock_gdfx_top_10_em_df['sync_time'] = str_now_date

        mongodb_util.save_mongo(stock_gdfx_top_10_em_df, db_name_constant.STOCK_GDFX_TOP_10)


# 十大股东+十大流通股东
def sync_stock_gdfx_free_top_10_one_day(str_day):
    real_time_quotes = em_stock_info_api.get_a_stock_info()
    real_time_quotes = real_time_quotes.loc[~(
        real_time_quotes['symbol'].isin(company_common_service_new_api.get_de_list_company()))]
    for real_time_one in real_time_quotes.itertuples():
        try:
            get_stock_gdfx_free_top_10_em(str_day, real_time_one.symbol)
            logger.info('同步股票前十大流通东:{},{}', real_time_one.symbol, real_time_one.name)
        except BaseException as e:
            logger.error('同步所有股票前十大流通股本异常:{},{}', real_time_one.symbol, e)
    logger.info('同步所有股票股东列表完成:{}', str_day)


if __name__ == '__main__':
    get_stock_gdfx_free_top_10_em('20250930', '300697')
    now_date_test = datetime.now()
    str_day_test = now_date_test.strftime('%Y-%m-%d')
    logger.info('同步所有股票前十大流通股本')
    sync_stock_gdfx_free_top_10_one_day(str_day_test)
